"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Redis = void 0;
const redis_tag_cache_1 = __importDefault(require("redis-tag-cache"));
const Errors_1 = require("../Errors");
const Lambda_1 = require("../Lambda");
const MAX_AGE_IN_SECS = 6 * 60 * 60;
let redisTagCache = null;
function getRedisTagCache() {
    const port = Lambda_1.getEnvConfig('REDIS_PORT');
    const host = Lambda_1.getEnvConfig('REDIS_ENDPOINT');
    if (!redisTagCache && port && host) {
        redisTagCache = new redis_tag_cache_1.default({
            defaultTimeout: MAX_AGE_IN_SECS,
            redis: {
                port: parseInt(port),
                host: host,
            },
        });
    }
    return redisTagCache;
}
// TODO implement promise timeout
class Redis {
    constructor() {
        this.redis = null;
        this.getOrCreateConnection = () => {
            if (!this.redis) {
                this.redis = getRedisTagCache();
                if (!this.redis)
                    throw new Errors_1.InternalServerError('No redis cluster found');
            }
            return this.redis;
        };
        this.get = async (key) => {
            const connection = this.getOrCreateConnection();
            return await connection.get(key);
        };
        this.set = async (key, data, tags, options) => {
            const connection = this.getOrCreateConnection();
            await connection.set(key, data, tags, options);
        };
        this.invalidate = async (...tags) => {
            const connection = this.getOrCreateConnection();
            await connection.invalidate(...tags);
        };
    }
}
exports.Redis = Redis;
