"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getExecutionContext = exports.setExecutionContext = exports.getEnvConfig = exports.buildHandler = void 0;
function buildHandler(router) {
    return async (request, context) => {
        context.callbackWaitsForEmptyEventLoop = false;
        const executionContext = extractExecutionContext(request, context);
        setExecutionContext(executionContext);
        const { response } = await router.route(request, context);
        return response;
    };
}
exports.buildHandler = buildHandler;
function extractExecutionContext(request, context) {
    var _a, _b;
    const identity = getIdentity(request);
    return {
        requestId: context.awsRequestId,
        path: request.path,
        method: request.httpMethod,
        identity: identity,
        sourceIp: (_b = (_a = request.requestContext) === null || _a === void 0 ? void 0 : _a.identity) === null || _b === void 0 ? void 0 : _b.sourceIp,
    };
}
function getIdentity(request) {
    var _a, _b;
    const apiKey = (_b = (_a = request.requestContext) === null || _a === void 0 ? void 0 : _a.identity) === null || _b === void 0 ? void 0 : _b.apiKey;
    if (apiKey) {
        const startOfApiKey = apiKey.substring(0, 5);
        return `apikey ${startOfApiKey}*****`;
    }
    return 'unknown';
}
function getEnvConfig(name) {
    return process.env[name];
}
exports.getEnvConfig = getEnvConfig;
const executionContext = {};
function setExecutionContext(context) {
    executionContext.requestId = context.requestId;
    executionContext.path = context.path;
    executionContext.method = context.method;
    executionContext.identity = context.identity;
    executionContext.sourceIp = context.sourceIp;
}
exports.setExecutionContext = setExecutionContext;
function getExecutionContext() {
    return executionContext;
}
exports.getExecutionContext = getExecutionContext;
