"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const winston_1 = __importDefault(require("winston"));
const Lambda_1 = require("../Lambda");
const { combine, timestamp, printf } = winston_1.default.format;
class Logger {
    constructor() {
        this.indexableProperties = {
            type: 'string',
            durationinMillis: 'number',
            statusCode: 'number',
            code: 'string',
            namespace: 'string',
            request: 'string',
        };
        this.format = printf(({ timestamp, level, message }) => {
            const stringifiedMessage = this.stringifyMessage(message);
            const indexedFields = this.indexLogProperties(message);
            const context = Lambda_1.getExecutionContext();
            return JSON.stringify({
                timestamp,
                level,
                message: stringifiedMessage,
                ...indexedFields,
                ...context,
            });
        });
        this.stringifyMessage = (message) => {
            if (typeof message === 'object' && message !== null) {
                return JSON.stringify(message);
            }
            return String(message);
        };
        this.log = (message) => this.logger.log(message);
        this.info = (message) => this.logger.info(message);
        this.debug = (message) => this.logger.debug(message);
        this.warn = (message) => this.logger.warn(message);
        this.error = (message) => this.logger.error(message);
        this.logger = winston_1.default.createLogger({
            format: combine(timestamp(), this.format),
            transports: [new winston_1.default.transports.Console()],
        });
    }
    indexLogProperties(message) {
        const indexedProperties = {};
        if (typeof message === 'object' && message !== null) {
            for (const [key, type] of Object.entries(this.indexableProperties)) {
                if (key in message) {
                    if (type === 'string' && ['string', 'number', 'boolean'].includes(typeof message[key])) {
                        indexedProperties[key] = String(message[key]);
                    }
                    if (type === 'number' && typeof message[key] === 'number') {
                        indexedProperties[key] = message[key];
                    }
                }
            }
        }
        return indexedProperties;
    }
}
exports.logger = new Logger();
