import { APIGatewayProxyEvent, Context } from 'aws-lambda';
import { LambdaRouter, RouterParams, HttpResponse } from 'lambda-router';
import { LoggerInterface } from '../Logger';
import { RouterInterface, Event, RouteInterface } from './RouterInterface';
export declare abstract class AbstractRouter implements RouterInterface {
    constructor(routerParams?: RouterParams);
    protected readonly router: LambdaRouter;
    protected readonly logger: LoggerInterface;
    protected readonly tracingEnabled: boolean;
    protected readonly allowedRequestProperties: string[];
    protected readonly headersToRemove: string[];
    addRoute: (routes: RouteInterface[]) => void;
    route: (event: APIGatewayProxyEvent, context: Context) => Promise<{
        isOk: boolean;
        endpoint: string;
        uri: string;
        response: {
            statusCode: number;
            body: string;
            headers: Record<string, string>;
        };
    }>;
    protected preprocessRequest: (event: Event, _context: Context, _path: string, _method: string) => void;
    protected logRequest: (event: Event, _context: Context, _path: string, _method: string) => void;
    /** Response on resource / method not found */
    protected abstract onUnknown(event: Event, context: Context, path: string, method: string): HttpResponse;
    /** Mutates the event/context and perform global scope validations */
    protected abstract beforeRoute(event: Event, context: Context, path: string, method: string): void;
}
