"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractRouter = void 0;
const lambda_router_1 = require("lambda-router");
const lodash_1 = require("lodash");
const Logger_1 = require("../Logger");
class AbstractRouter {
    constructor(routerParams) {
        var _a, _b, _c, _d, _e, _f, _g;
        this.allowedRequestProperties = [
            'headers',
            'queryStringParameters',
            'multiValueQueryStringParameters',
            'pathParameters',
            'rawBody',
            'isBase64Encoded',
        ];
        this.headersToRemove = ['authorization', 'x-api-key'];
        this.addRoute = (routes) => {
            for (const route of routes) {
                const { path } = route;
                if (route.get)
                    this.router.get(path, route.get);
                if (route.post)
                    this.router.post(path, route.post);
                if (route.put)
                    this.router.put(path, route.put);
                if (route.delete)
                    this.router.delete(path, route.delete);
            }
        };
        this.route = async (event, context) => {
            const response = await this.router.route(event, context);
            if (this.tracingEnabled)
                this.logger.info(response);
            return response;
        };
        this.preprocessRequest = (event, _context, _path, _method) => {
            for (const prop in this.allowedRequestProperties) {
                delete event[prop];
            }
            if (typeof lodash_1.get(event, 'pathParameters.path') === 'string') {
                delete event.pathParameters.path;
            }
            for (const header of Object.keys(event.headers)) {
                if (this.headersToRemove.includes(header.toLowerCase())) {
                    delete event.headers[header];
                }
            }
        };
        this.logRequest = (event, _context, _path, _method) => {
            if (this.tracingEnabled)
                this.logger.info(event);
        };
        this.router = lambda_router_1.Router({
            extractPathParameters: (_a = routerParams === null || routerParams === void 0 ? void 0 : routerParams.extractPathParameters) !== null && _a !== void 0 ? _a : true,
            includeErrorStack: (_b = routerParams === null || routerParams === void 0 ? void 0 : routerParams.includeErrorStack) !== null && _b !== void 0 ? _b : false,
            cors: (_c = routerParams === null || routerParams === void 0 ? void 0 : routerParams.cors) !== null && _c !== void 0 ? _c : false,
            parseBody: (_d = routerParams === null || routerParams === void 0 ? void 0 : routerParams.parseBody) !== null && _d !== void 0 ? _d : true,
            decodeEvent: (_e = routerParams === null || routerParams === void 0 ? void 0 : routerParams.decodeEvent) !== null && _e !== void 0 ? _e : true,
            normalizeHeaders: (_f = routerParams === null || routerParams === void 0 ? void 0 : routerParams.normalizeHeaders) !== null && _f !== void 0 ? _f : true,
        });
        this.tracingEnabled = (_g = routerParams === null || routerParams === void 0 ? void 0 : routerParams.tracingEnabled) !== null && _g !== void 0 ? _g : true;
        this.logger = Logger_1.logger;
        this.router.unknown(this.onUnknown);
        this.router.beforeRoute(this.preprocessRequest);
        this.router.beforeRoute(this.logRequest);
        this.router.beforeRoute(this.beforeRoute);
    }
}
exports.AbstractRouter = AbstractRouter;
