"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateRequest = void 0;
const Errors_1 = require("../Errors");
function validateRequest(schemas) {
    return function validate(_target, _propertyKey, descriptor) {
        let originalMethod = descriptor.value;
        descriptor.value = async function (event, context) {
            const { pathParameters, queryStringParameters, headers, rawBody } = event;
            const { pathParametersSchema, queryStringParametersSchema, headersSchema, bodySchema } = schemas;
            let body;
            if (bodySchema) {
                try {
                    body = JSON.parse(rawBody || '');
                }
                catch (e) {
                    throw new Errors_1.BadRequest('Malformed JSON body');
                }
            }
            try {
                if (pathParametersSchema)
                    await pathParametersSchema.validateAsync(pathParameters);
                if (queryStringParametersSchema)
                    await queryStringParametersSchema.validateAsync(queryStringParameters);
                if (headersSchema)
                    await headersSchema.validateAsync(headers);
                if (bodySchema)
                    await bodySchema.validateAsync(body);
            }
            catch (e) {
                throw new Errors_1.BadRequest(String(e));
            }
            return originalMethod.apply(this, [event, context]);
        };
    };
}
exports.validateRequest = validateRequest;
